@@ -1,8 +1,10 @@
 import click
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
 from opnsense_cli.callbacks.click import \
-    formatter_from_formatter_name, bool_as_string, available_formats, int_as_string, tuple_to_csv
+    formatter_from_formatter_name, bool_as_string, available_formats, int_as_string, tuple_to_csv, \
+    resolve_linked_names_to_uuids
 from opnsense_cli.types.click_param_type.int_or_empty import INT_OR_EMPTY
+from opnsense_cli.types.click_param_type.csv import CSV
 from opnsense_cli.commands.plugin.haproxy import haproxy
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.plugin.haproxy import Settings, Service
@@ -602,6 +604,8 @@ def show(haproxy_acl_svc: HaproxyAclFacade, **kwargs):
 @click.option(
     '--nbsrv_backend',
     help=('Use the specified backend to count usable servers. Leave empty to use the current backend.'),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -676,6 +680,8 @@ def show(haproxy_acl_svc: HaproxyAclFacade, **kwargs):
 @click.option(
     '--queryBackend',
     help=('None'),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -683,6 +689,8 @@ def show(haproxy_acl_svc: HaproxyAclFacade, **kwargs):
 @click.option(
     '--allowedUsers',
     help=('None'),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -690,6 +698,8 @@ def show(haproxy_acl_svc: HaproxyAclFacade, **kwargs):
 @click.option(
     '--allowedGroups',
     help=('None'),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -1252,6 +1262,8 @@ def create(haproxy_acl_svc: HaproxyAclFacade, **kwargs):
 @click.option(
     '--nbsrv_backend',
     help=('Use the specified backend to count usable servers. Leave empty to use the current backend.'),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
@@ -1316,18 +1328,24 @@ def create(haproxy_acl_svc: HaproxyAclFacade, **kwargs):
 @click.option(
     '--queryBackend',
     help=('None'),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
 @click.option(
     '--allowedUsers',
     help=('None'),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
 @click.option(
     '--allowedGroups',
     help=('None'),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
