@@ -1,8 +1,10 @@
 import click
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
 from opnsense_cli.callbacks.click import \
-    formatter_from_formatter_name, bool_as_string, available_formats, int_as_string, tuple_to_csv
+    formatter_from_formatter_name, bool_as_string, available_formats, int_as_string, tuple_to_csv, \
+    resolve_linked_names_to_uuids
 from opnsense_cli.types.click_param_type.int_or_empty import INT_OR_EMPTY
+from opnsense_cli.types.click_param_type.csv import CSV
 from opnsense_cli.commands.plugin.haproxy import haproxy
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.plugin.haproxy import Settings, Service
@@ -153,6 +155,8 @@ def show(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--linkedServers',
     help='Add servers to this backend.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -160,6 +164,8 @@ def show(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--linkedResolver',
     help='Select the custom resolver configuration that should be used for all servers in this backend.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -206,6 +212,8 @@ def show(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--healthCheck',
     help='Select health check for servers in this backend.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -260,6 +268,8 @@ def show(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--linkedMailer',
     help='Select an e-mail alert configuration. An e-mail is sent when the state of a server changes.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -485,6 +495,8 @@ def show(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--basicAuthUsers',
     help='Basic auth users.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -492,6 +504,8 @@ def show(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--basicAuthGroups',
     help='Basic auth groups.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -594,6 +608,8 @@ def show(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--linkedActions',
     help='Choose rules to be included in this backend pool.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -601,6 +617,8 @@ def show(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--linkedErrorfiles',
     help='Choose error messages to be included in this backend pool.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -682,7 +700,6 @@ def create(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 
         }
     }
-
     result = haproxy_backend_svc.create_backend(json_payload)
 
     CliOutputFormatter(result, kwargs['output'], kwargs['cols'].split(",")).echo()
@@ -751,12 +768,16 @@ def create(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--linkedServers',
     help='Add servers to this backend.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
 @click.option(
     '--linkedResolver',
     help='Select the custom resolver configuration that should be used for all servers in this backend.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
@@ -798,6 +819,8 @@ def create(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--healthCheck',
     help='Select health check for servers in this backend.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
@@ -846,6 +869,8 @@ def create(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--linkedMailer',
     help='Select an e-mail alert configuration. An e-mail is sent when the state of a server changes.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
@@ -1050,12 +1075,16 @@ def create(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--basicAuthUsers',
     help='Basic auth users.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
 @click.option(
     '--basicAuthGroups',
     help='Basic auth groups.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
@@ -1148,12 +1177,16 @@ def create(haproxy_backend_svc: HaproxyBackendFacade, **kwargs):
 @click.option(
     '--linkedActions',
     help='Choose rules to be included in this backend pool.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
 @click.option(
     '--linkedErrorfiles',
     help='Choose error messages to be included in this backend pool.',
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
