@@ -2,6 +2,7 @@ import click
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
 from opnsense_cli.callbacks.click import \
     formatter_from_formatter_name, bool_as_string, available_formats, resolve_linked_names_to_uuids
+from opnsense_cli.types.click_param_type.csv import CSV
 from opnsense_cli.commands.plugin.haproxy import haproxy
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.plugin.haproxy import Settings, Service
@@ -100,6 +101,7 @@ def show(haproxy_group_svc: HaproxyGroupFacade, **kwargs):
     '--members',
     help=('The comma seperated user uuids of the group.'),
     callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -177,6 +179,7 @@ def create(haproxy_group_svc: HaproxyGroupFacade, **kwargs):
     '--members',
     help=('The comma seperated user uuids of the group'),
     callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None
 )
