@@ -1,8 +1,10 @@
 import click
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
 from opnsense_cli.callbacks.click import \
-    formatter_from_formatter_name, bool_as_string, available_formats, int_as_string, tuple_to_csv
+    formatter_from_formatter_name, bool_as_string, available_formats, int_as_string, tuple_to_csv, \
+    resolve_linked_names_to_uuids
 from opnsense_cli.types.click_param_type.int_or_empty import INT_OR_EMPTY
+from opnsense_cli.types.click_param_type.csv import CSV
 from opnsense_cli.commands.plugin.haproxy import haproxy
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.plugin.haproxy import Settings, Service
@@ -170,6 +172,8 @@ def show(haproxy_server_svc: HaproxyServerFacade, **kwargs):
             'Specify the uuid of the resolver that the server template should look at '
             'to discover available services via DNS.'
     ),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
@@ -428,6 +432,8 @@ def create(haproxy_server_svc: HaproxyServerFacade, **kwargs):
             'Specify the uuid of the resolver that the server template should look at '
             'to discover available services via DNS.'
     ),
+    callback=resolve_linked_names_to_uuids,
+    type=CSV,
     show_default=True,
     default=None,
     required=False,
